@@ -3,7 +3,7 @@ from .boolean import Boolean
 from .collection import Collection
 from .color import Color
 from .date import Date
-from .file import File
+from .file import File, Image
 from .number import Number
 from .select import Select, MultiSelect
 from .text import Text
